@@ -50,26 +50,28 @@ class Target:
     :type target: string
     """
     def __init__(self, target):
+        # Here, we do not check that path exists.
+        # It is checked in check_availability()
         self.logger = logging.getLogger('Vitalus.Target')
         self.logger.debug("Read target %s", target)
         self.target = target
         self.ttype = self._detect_target_type()
 
-        if self.is_dir():
+        if self.is_local():
             self.path = target
         elif self.is_ssh():
             self.login, self.path = target.split(':')
             self.domain = self.login.split('@')[1]
-        if not os.path.exists(self.path):
-            raise TARGETError("Target %s unreachable" % self.target)
+        if self.path is None:
+            raise TARGETError("The path is not correct in %s" % self.target)
 
-    def is_dir(self):
+    def is_local(self):
         """
         Check if the target is a directory
 
         :returns: bool -- True if it is a directory
         """
-        if self.ttype == 'DIR':
+        if self.ttype == 'LOCAL':
             return True
         else:
             return False
@@ -93,20 +95,22 @@ class Target:
         :raises: TARGETError -- if not available
         """
         if self.ttype == 'SSH':
+            # TODO; here we check the connection.
+            # We may check also the filepath
             sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             try:
                 sock.connect((self.domain, 22))
             except socket.error:
-                raise TARGETError("Target %s unreachable" % self.target)
-        elif self.ttype == 'DIR':
+                raise TARGETError("SSH target %s unreachable" % self.target)
+        elif self.ttype == 'LOCAL':
             if not os.path.exists(self.path):
-                raise TARGETError("Target %s unreachable" % self.target)
+                raise TARGETError("Local target %s unreachable" % self.target)
 
     def _detect_target_type(self):
         """
         Return the target type
         SSH if matches name@domaine.tld:dir
-        DIR if it's a directory
+        LOCAL if it's a directory
         """
         #if re.match('[a-zA-Z0-9+_\-\.]+@[0-9a-zA-Z][.-0-9a-zA-Z]*.[a-zA-Z]+\:.*', self.target):
         if re.match('[a-zA-Z0-9+_\-\.]+@[a-zA-Z0-9+_\-\.]+\:.*', self.target):
@@ -114,8 +118,8 @@ class Target:
             self.logger.debug("The target %s looks like SSH", self.target)
             return 'SSH'
         else:
-            self.logger.debug("The target %s looks like DIR", self.target)
-            return 'DIR'
+            self.logger.debug("The target %s looks like LOCAL", self.target)
+            return 'LOCAL'
 
 
 class Job:
@@ -132,14 +136,16 @@ class Job:
     :type destination: string
     :param period: Min duration between two backups (in seconds)
     :type period: float
-    :param snapshot: Activate snapshots
-    :type snapshot: bool
+    :param snapshot: Activate (True) or desactivate (False) snapshots or simple (None) copy
+    :type snapshot: bool or None
     :param duration: How many days snapshots are kept
     :type duration: int
     :param keep: How many snapshots are (at least) kept
     :type keep: int
     :param force: overide the timebase check, no min. duration.
     :type filter: bool
+    :param guid: (uid, gid) for destination
+    :type guid: tuple
     :param filter: Rsync filters
     :type filter: list
 
@@ -148,9 +154,11 @@ class Job:
 
         Source and destination path can be either real path
         or a ssh login joined to the path by a : character.
+
+        if uid or gid are None, files owner are not changed
     """
 
-    def __init__(self, log_dir, name, source, destination, period, snapshot, duration, keep, force, filter):
+    def __init__(self, log_dir, name, source, destination, period, snapshot, duration, keep, force, guid, filter):
 
         self.name = name
         self.source = Target(source)
@@ -165,6 +173,8 @@ class Job:
         self.now = datetime.datetime.now()
         self.current_date = self.now.strftime("%Y-%m-%d_%Hh%Mm%Ss")
 
+        self.dest_uid, self.dest_gid = guid
+
         self.backup_log_dir = log_dir
 
         self.logger = logging.getLogger('Vitalus.Job')
@@ -177,7 +187,7 @@ class Job:
         self.job_logger.setLevel(logging.INFO)
 
         #Set previous and current backup paths
-        self.previous_backup_path = None
+        self.previous_backup_path = None  # will be detected later
         self.current_backup_path = None
 
 #    def _check_disk_usage(self):
@@ -185,7 +195,7 @@ class Job:
 #        Check the disk usage
 #        :raises TARGETError: if low disk space
 #        """
-#        if self.destination.is_dir():
+#        if self.destination.is_local():
 #            #TODO, change the criterion
 #            pass
 #            #if psutil.disk_usage(self.destination)[2] < utils.get_folder_size(self.source):
@@ -248,7 +258,7 @@ class Job:
         path = os.path.join(self.destination.path, self.name)
 
         self.destination.check_availability()
-        if self.destination.is_dir():
+        if self.destination.is_local():
             filenames = os.listdir(path)
         elif self.destination.is_ssh():
                 command = ['ssh', '-t', self.destination.login, 'ls', '-1', path]
@@ -266,7 +276,7 @@ class Job:
         self.logger.debug("Backups to delete %s ", to_delete)
 
         self.destination.check_availability()
-        if self.destination.is_dir():
+        if self.destination.is_local():
             for element in to_delete:
                 self.logger.debug("Remove backup %s", element)
                 try:
@@ -291,7 +301,7 @@ class Job:
         """
         path = os.path.join(self.destination.path, self.name)
         self.destination.check_availability()
-        if self.destination.is_dir():
+        if self.destination.is_local():
             if not os.path.isdir(path):
                 return None
             #filenames = [os.path.join(path, el) for el in os.listdir(path)]
@@ -324,15 +334,29 @@ class Job:
         Create dirs
         """
         self.destination.check_availability()
-        if self.destination.is_dir():
-            if self.snapshot:
+
+        # Define current backup path
+        if self.snapshot is True:
+            self.current_backup_path = os.path.join(self.destination.path, self.name, str(self.current_date))
+        elif self.snapshot is False:
+            self.current_backup_path = os.path.join(self.destination.path, self.name, str(self.current_date))
+        elif self.snapshot is None:
+            self.current_backup_path = os.path.join(self.destination.path, self.name)
+        else:
+            raise ValueError('Wrong snapshot value (True, False or None)')
+
+        # Make dirs
+        if self.destination.is_local():
+            if self.snapshot is True:
                 os.makedirs(self.current_backup_path)  # This one does not exist!
-            else:
+            elif self.snapshot is False:
                 if self.previous_backup_path is None:
                     os.makedirs(self.current_backup_path, exist_ok=True)
                 else:
                     #Move dir to set the new date in the path
                     os.rename(self.previous_backup_path, self.current_backup_path)
+            elif self.snapshot is None:
+                os.makedirs(self.current_backup_path, exist_ok=True)
         elif self.destination.is_ssh():
             #Create dirs
             command = ['ssh', '-t', self.destination.login, 'mkdir', '-p', self.current_backup_path]
@@ -354,10 +378,12 @@ class Job:
         # stat: file rate stats
         # delete: delete extraneous files from dest dirs
         # delete-excluded: also delete excluded files from dest dirs
+        # L: turn symlinks to dir/file
         command.append('-avh')
         command.append('--stats')
         command.append('--delete')
         command.append('--delete-excluded')
+        command.append('-L')
 
         # z: compress the flux if transfert thought a network
         if (self.source.is_ssh() or self.destination.is_ssh()):
@@ -411,9 +437,9 @@ class Job:
             self.job_logger.info('Errors:')
             self.job_logger.info(stderr.decode())
 
-    def run(self):
+    def run(self, uid=None, gid=None):
         """
-        Run the job
+        Run the job.
         """
         self.logger.debug('Start job: %s', self.name)
         #TODO rewriting and integration:
@@ -421,7 +447,6 @@ class Job:
 
         try:
             last_date = self._get_last_backup()
-            self.current_backup_path = os.path.join(self.destination.path, self.name, str(self.current_date))
             if last_date is None:
                 #It means that this is the first backup.
                 self.previous_backup_path = None
@@ -454,21 +479,41 @@ class Job:
                 self._delete_old_files(days=self.duration, keep=self.keep)
 
                 # Create symlink
-                last = os.path.join(self.destination.path, self.name, 'last')
-                if self.destination.is_dir():
-                    if os.path.islink(last):
-                        os.remove(last)
-                    os.chdir(os.path.dirname(self.current_backup_path))
-                    try:
-                        os.symlink(os.path.basename(self.current_backup_path), last)
-                    except FileExistsError:
-                        self.logger.warning('The symlink %s could not be created because a file exists', last)
-                    except AttributeError:
-                        self.logger.warning('Attribute error for symlink. Job: %s', self.name)
-                elif self.destination.is_ssh():
-                    pass
-                    #TODO Create symlink
+                if self.snapshots is True or self.snapshots is False:
+                    last = os.path.join(self.destination.path, self.name, 'last')
+                    if self.destination.is_local():
+                        if os.path.islink(last):
+                            os.remove(last)
+                        os.chdir(os.path.dirname(self.current_backup_path))
+                        try:
+                            os.symlink(os.path.basename(self.current_backup_path), last)
+                        except FileExistsError:
+                            self.logger.warning('The symlink %s could not be created because a file exists', last)
+                        except AttributeError:
+                            self.logger.warning('Attribute error for symlink. Job: %s', self.name)
+                    elif self.destination.is_ssh():
+                        self.logger.warning('symlink for SSH not yet implemented')
+                        #TODO Create symlink
+
+                # UID/GID
+                if self.dest_uid and self.dest_gid:
+                    self._chown_destination(self.dest_uid, self.dest_gid)
+                elif self.dest_uid or self.dest_gid:
+                    self.logger.error('uid or gid missing')
 
                 self.logger.info("Backup %s done", self.name)
         except TARGETError as e:
             self.logger.warning(e)
+
+    def _chown_destination(self, uid, gid):
+        """
+        Change owner of files in destination
+
+        :param uid: user ID
+        :param gid: group ID
+        """
+        if self.destination.is_local():
+            self.logger.debug('chown %s %s for %s' % (uid, gid, self.current_backup_path))
+            utils.r_chown(self.current_backup_path, uid, gid)
+        elif self.destination.is_ssh():
+            self.logger.warning('chown for SSH not yet implemented')
