@@ -32,11 +32,13 @@ class Vitalus:
 
     :params log_path: directory for logs and database
     :type log_path: string
+    :params log_rotation: How many days logs are kept
+    :type log_path: int
     :param force: overide the timebase check, no min. duration.
     :type filter: bool
 
     """
-    def __init__(self, log_path='~/.backup', force=False):
+    def __init__(self, log_path='~/.backup', log_rotation=30, force=False):
         # Variables
         self.jobs = []
         self.terminate = False
@@ -55,7 +57,7 @@ class Vitalus:
         log_rotator = logging.handlers.TimedRotatingFileHandler(LOG_PATH,
                                                                 when='midnight',
                                                                 interval=1,
-                                                                backupCount=30,
+                                                                backupCount=log_rotation,
                                                                 encoding=None,
                                                                 delay=False,
                                                                 utc=False)
@@ -146,14 +148,19 @@ class Vitalus:
         #nice
         p.nice = 15
 
-    def set_destination(self, destination):
+    def set_destination(self, destination, guid=(None, None)):
         """ Set the destination of the backup
+        if uid or gid are None, files owner are not changed
 
         :param destination: destination path
         :type destination: string
+        :param guid: (uid, gid) for destination
+        :type guid: tuple
+
         """
         self.logger.debug("Set destination: %s", destination)
         self.destination = destination
+        self.guid = guid
 
     #TODO: filter -> *filter ?
     def add_job(self, name, source, period=24, history=False, duration=50, keep=10, filter=None):
@@ -167,8 +174,8 @@ class Vitalus:
         :type destination: string
         :param period: min time (hours) between backups
         :type period: float
-        :param history: Activate snapshots
-        :type history: bool
+        :param history: Activate (True) or desactivate (False) snapshots or simple (None) copy
+        :type history: bool or None
         :param duration: How many days snapshotss are kept
         :type duration: int
         :param keep: How many snapshots are (at least) kept
@@ -179,28 +186,38 @@ class Vitalus:
         .. note::
             filter syntax is the same of rsync. See "FILTER RULES" section
             in the rsync man page.
+
+            history: if True or False, the date is written in the path.
+            It leaves you the possibility to switch on/off the history.
+            None does not put a date in the path. Thus, it remains invariant.
         """
         if name in self.jobs:
             self.critical("%s already present in the job list. Job's name should be uniq.", name)
             return
 
-        if self.destination:
+        if self.destination: #Raise something if it's None
             period_in_seconds = period * 3600
             self.logger.debug("add job: %s", name)
             try:
                 self.jobs.append(Job(self.backup_log_dir, name, source,
                                      self.destination, period_in_seconds,
-                                     history, duration, keep, self.force, filter))
+                                     history, duration, keep, self.force,
+                                     self.guid, filter))
             except TARGETError as e:
                 # We abort this job
-                self.logger.error(e) 
+                self.logger.error(e)
+            except:
+                self.logger.exception('Exception raised in add_job()')
 
     def run(self):
         """ Run all jobs """
-        for job in self.jobs:
-            job.run()
-        self._release_pidfile()
-        self.logger.info('The script exited gracefully')
+        try:
+            for job in self.jobs:
+                job.run()
+            self._release_pidfile()
+            self.logger.info('The script exited gracefully')
+        except:
+            self.logger.exception('Exception raised in run()')
 
 if __name__ == '__main__':
     #An example...
